generation

package
v1.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 12, 2026 License: GPL-3.0 Imports: 5 Imported by: 0

Documentation

Overview

Package generation handles web shell generation and export.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Wizard

func Wizard(base64Session structure.B64Session)

Wizard guides the user through generating and exporting a web shell.

Types

This section is empty.

Directories

Path Synopsis
Package generator provides web shell template processing and variable substitution.
Package generator provides web shell template processing and variable substitution.
Package template contains the web shell PHP payload template.
Package template contains the web shell PHP payload template.

Jump to