password

package
v1.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 26, 2026 License: GPL-3.0 Imports: 3 Imported by: 0

Documentation

Overview

Package password provides password hashing, verification, and key generation utilities.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ForgeHash

func ForgeHash(transitPassword []byte) []byte

ForgeHash generates a bcrypt hash from transit password bytes.

func ForgeKey

func ForgeKey(transitPasswordBytes []byte) []byte

ForgeKey creates a 32-byte encryption key from transit password bytes.

func ForgeTransitPasswordBytes

func ForgeTransitPasswordBytes(password string) []byte

ForgeTransitPasswordBytes creates a 15-byte transit password from a string password.

func VerifyPassword

func VerifyPassword(transitPasswordBytes []byte, hash []byte) bool

VerifyPassword verifies if transit password bytes match the provided hash.

Types

This section is empty.

Jump to