field

package
v1.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 26, 2026 License: GPL-3.0 Imports: 6 Imported by: 0

Documentation

Overview

Package field provides interactive field input validation and collection.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetChannel

func GetChannel(prompt string) string

GetChannel prompts the user for a valid channel cookie name (1-50 characters).

func GetHash

func GetHash(prompt string, confirmationPrompt string) []byte

GetHash prompts the user for a password with confirmation and returns the hashed version.

func GetName

func GetName(prompt string, sessionList [][]string) string

GetName prompts the user for a valid session name (1-50 characters).

func GetPassword

func GetPassword(prompt string, expectedHash []byte) ([]byte, []byte)

GetPassword prompts the user for a password and returns transit password and attacker key.

func GetURL

func GetURL(prompt string) string

GetURL prompts the user for a valid URL.

Types

This section is empty.

Jump to