Documentation
¶
Overview ¶
Package generation handles web shell generation and export.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Wizard ¶
func Wizard(base64Session structure.B64Session)
Wizard guides the user through generating and exporting a web shell.
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package generator provides web shell template processing and variable substitution.
|
Package generator provides web shell template processing and variable substitution. |
|
Package template contains the web shell PHP payload template.
|
Package template contains the web shell PHP payload template. |
Click to show internal directories.
Click to hide internal directories.