Documentation
¶
Overview ¶
Package password provides password hashing, verification, and key generation utilities.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ForgeTransitPasswordBytes ¶
ForgeTransitPasswordBytes creates a 15-byte transit password from a string password.
func VerifyPassword ¶
VerifyPassword verifies if transit password bytes match the provided hash.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.