Documentation
¶
Overview ¶
Package field provides interactive field input validation and collection.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetChannel ¶
GetChannel prompts the user for a valid channel cookie name (1-50 characters).
func GetHash ¶
GetHash prompts the user for a password with confirmation and returns the hashed version.
func GetPassword ¶
GetPassword prompts the user for a password and returns transit password and attacker key.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.